#ifndef NT2_INCLUDE_FUNCTIONS_EQ_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_EQ_HPP_INCLUDED

#include <nt2/operator/include/functions/eq.hpp>

#endif
